page = """
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>SSPAF_TITLE</title>
</head>
<script src="sspaf.js" defer></script>
<body>
    SSPAF_HEADER
    <div id="content" style="width: 100%; height: 100%;">SSPAF_INDEX</div>
    SSPAF_FOOTER
</body>
</html>
"""